@@ -36,10 +36,12 @@ def create_engine(name='self', *args, **kwargs):
     global ENGINES
     global ASYNC_ENGINES
 
-    engine_factory = create_async_engine
     databases = kwargs.pop('databases', None) or DATABASES
     use_async = kwargs.get('use_async', False)
 
+    engine_factory = create_async_engine
+    if not use_async:
+        engine_factory = sqlalchemy.create_engine
     engines = ENGINES if not use_async else ASYNC_ENGINES
     if name not in engines:
         engines[name] = databases[name]\
